"""
This is the celtux.chroot module, it provides a class for bootstrapping
and executing commands within a chroot.

Author:    Niall Walsh
Copyright: Copyright (C) 2013 Niall Walsh <niallwalsh@users.berlios.de>
License:   GPL-2
"""

import fll.chroot
import os

class ChrootError(fll.chroot.ChrootError):
    """
    An Error class for use by Chroot.
    """
    pass


class Chroot(fll.chroot.Chroot):
    """
    A class which provides the ability to bootstrap and execute commands
    within a chroot.

    Options        Type   Description
    --------------------------------------------------------------------------
    rootdir      - (str)  path to root of chroot
    architecture - (str)  architecture of chroot
    config       - (dict) the 'chroot' section of fll.config.Config object
    """

    def detectLinuxVersion(self):
         """Return version string of all installed linux-image."""
         kvers = [f[f.find('-')+1:] for f in os.listdir(os.path.join(self.rootdir, 'boot')) if f.startswith('vmlinuz-') or f.startswith('vmlinux-')]
         kvers.sort
         return(kvers)

    def makeInitramfs(self):
        """Generate the initramfs if update-initramfs was diverted"""
        if '/usr/sbin/update-initramfs' in self.diverts and os.path.isfile(self.chroot_path('/usr/sbin/update-initramfs')):
            kvers = self.detectLinuxVersion()
            for k in kvers:
                cmd = 'update-initramfs -c -k %s' % k
                self.cmd(cmd.split())
