"""
This is the sunxi.distro module, it abstracts the 'distro' section of an
sunxi.config.Config object. It provides a hook for distro specific actions
and includes (for now) sunxi specific actions.

Author:    Niall Walsh
Copyright: Copyright (C) 2013 Niall Walsh <niallwalsh@users.berlios.de>
License:   GPL-2
"""

import celtux.distro
import os

class DistroError(celtux.distro.DistroError):
    pass


class Distro(celtux.distro.Distro):
    """
    A class for distro preparing a chroot.

    Options  Type                Description
    --------------------------------------------------------------------------
    chroot - (fll.chroot.Chroot) fll.chroot.Chroot object
    config - (dict)              the 'distro' section of fll.config.Config object
    """

    def run(self):
        super(Distro, self).run()
        self.create_file('/etc/initramfs-tools/modules')
        #self.makeImages()

    def create_file(self, filename, mode=0644):
        if filename == '/etc/initramfs-tools/modules':
            try:
                fh = None
                fh = open(self.chroot.chroot_path(filename), 'w')
                print >>fh, """\
mmc_core
mmc_power
sunxi-mci
mmc_block
ushc
sw_ahci_platform
lcd
hdmi
ump
disp
mali
mali_drm
fbcon"""
            except IOError:
                raise ChrootError('failed to write: ' + filename)
            finally:
                if fh:
                    fh.close()
                    os.chmod(self.chroot.chroot_path(filename), mode)
        else:
            super(Distro, self).create_file(filename, mode=mode)

    def makeImages(self):
        """Generate the uboot images if mkimage is installed"""
        pihook = '/etc/kernel/postinst.d/zs-sunxi-image'
        if os.path.isfile(self.chroot.chroot_path(pihook)):
            kvers = self.chroot.detectLinuxVersion()
            for k in kvers:
                cmd = '%s %s' % (pihook, k)
                self.chroot.cmd(cmd.split())
